# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`vulnerability`](#vulnerability): The top-level class of the vulnerability module.
* [`vulnerability::clear_facter_cache`](#vulnerabilityclear_facter_cache): Clear the `cve_list` facter cache.
* [`vulnerability::guard`](#vulnerabilityguard): Guard the system for vulnerabilities.
* [`vulnerability::install`](#vulnerabilityinstall): This class ensures the installation of `grype` in a correct way so that Puppet can start guarding the vulnerabilities on this system.
* [`vulnerability::install::linux`](#vulnerabilityinstalllinux): This class takes care of installing `grype` on linux systems.
* [`vulnerability::install::windows`](#vulnerabilityinstallwindows): This class takes care of installing `grype` on windows systems.
* [`vulnerability::setup`](#vulnerabilitysetup): Ensure the your vulnerability scanning is setup correctly.
* [`vulnerability::update`](#vulnerabilityupdate): Update the `grype` vulnerability database from the URL specified as `vulnerability::setup::update_url`.

### Resource types

* [`vulnerability_status`](#vulnerability_status): Manage the status of the vulnerabilities on your system.  Using this type, you can start to manage the number of vulnerabilities you allow on

### Functions

* [`vulnerability::affected_files`](#vulnerabilityaffected_files): get the list of files that are affected by a specified vulnerability
* [`vulnerability::detected`](#vulnerabilitydetected): Determine if a specified vulnerability is found on this system
* [`vulnerability::severity`](#vulnerabilityseverity): Return an array of vulnerability id's of a specified level on this system
* [`vulnerability::validate`](#vulnerabilityvalidate): Validate that your system doesn't have vulnerabilities above a specified level. When your system **does** contain the vulnerabilities, signal

### Data types

* [`Vulnerability::Fix_state`](#vulnerabilityfix_state): The fix state of the CVE.
* [`Vulnerability::Level`](#vulnerabilitylevel): The severity level of the CVE

## Classes

### <a name="vulnerability"></a>`vulnerability`

vulnerability::vulnerability

This class ensures that the correct version of [`grype`](https://github.com/anchore/grype) is installed and configured and that on the specified interval your systems are scanned for vulnerabilities.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `vulnerability` class:

* [`update`](#update)
* [`guard`](#guard)

##### <a name="update"></a>`update`

Data type: `Boolean`

Update the vulnerability database on every Puppet run.
When you set this value to `true`, Puppet will check the vulnerability database on every run and update it when it detects a new version.
Although setting it to true is the best setting security-wise, it can introduce dynamic changes to your Puppet run's that you don't want. When you want more controlled updates, set this value to false and make sure that the `vulnerability::update` class is scheduled in some other way.
Even when you set this value to `false`, Puppet will do an update on the initial run where [`grype`](https://github.com/anchore/grype) is installed. This is required to at least have an initial vulnerability database.

##### <a name="guard"></a>`guard`

Data type: `Boolean`

When you set this value to `true`, Puppet start's to guard the number of vulnerabilities on your system.
Check the [`::vulnerability::guard` class](./guard.html) for details.
The default value is `false` meaning no automatic checks on the vulnerability status.

### <a name="vulnerabilityclear_facter_cache"></a>`vulnerability::clear_facter_cache`

vulnerability::clear_facter_cache

This measn that on the next Puppet run, the fact will be determined again.


See the file "LICENSE" for the full license governing this code.

### <a name="vulnerabilityguard"></a>`vulnerability::guard`

vulnerability::guard

When you include this class into your catalog, Puppet starts to guard your system. Meaning it will check on every Puppet run's if the number of found vulnerabilities is lower than the maximum number you have specified.

When Puppet detects that more vulnerabilities are found on your system than you specified, Puppet will fail.

You will need to monitor the status of Puppet runs on the Puppet server and take appropriate actions.

Sometimes you know about a set of vulnerabilities, and you don't want Puppet to report on this. If this is the case, add the vulnerability ID to the `allow_list`. Puppet will then allow this specific CVE on your system without reporting and/or failing on it.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `vulnerability::guard` class:

* [`allow_list`](#allow_list)
* [`critical`](#critical)
* [`high`](#high)
* [`low`](#low)
* [`medium`](#medium)
* [`negligible`](#negligible)
* [`unknown`](#unknown)

##### <a name="allow_list"></a>`allow_list`

Data type: `Array[String[1]]`

The list of vulnerability id's you want to allow on your system.
When a found vulnerability is on your allow list, it will not count in the number
  of identified vulnerabilities on the system.

##### <a name="critical"></a>`critical`

Data type: `Optional[Integer]`

The number of critical vulnerabilities you allow on your system before Puppet throws an error.
The default is `0`.

##### <a name="high"></a>`high`

Data type: `Optional[Integer]`

The number of high vulnerabilities you allow on your system before Puppet throws an error.
The default is `Undef`. Meaning Puppet doesn't guard this.

##### <a name="low"></a>`low`

Data type: `Optional[Integer]`

The number of low vulnerabilities you allow on your system before Puppet throws an error.
The default is `Undef`. Meaning Puppet doesn't guard this.

##### <a name="medium"></a>`medium`

Data type: `Optional[Integer]`

The number of low vulnerabilities you allow on your system before Puppet throws an error.
The default is `Undef`. Meaning Puppet doesn't guard this.

##### <a name="negligible"></a>`negligible`

Data type: `Optional[Integer]`

The number of negligible vulnerabilities you allow on your system before Puppet throws an error.
The default is `Undef`. Meaning Puppet doesn't guard this.

##### <a name="unknown"></a>`unknown`

Data type: `Optional[Integer]`

The number of unkown vulnerabilities you allow on your system before Puppet throws an error.
The default is `Undef`. Meaning Puppet doesn't guard this.

### <a name="vulnerabilityinstall"></a>`vulnerability::install`

vulnerability::install

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `vulnerability::install` class:

* [`version`](#version)
* [`base_url`](#base_url)

##### <a name="version"></a>`version`

Data type: `String[1]`

The version of `grype` to install.

##### <a name="base_url"></a>`base_url`

Data type: `String[1]`

The base part of the URL where to download grype from.
The default is: `https://github.com/anchore/grype/releases/download`, meaning we download directly from the original github source.

### <a name="vulnerabilityinstalllinux"></a>`vulnerability::install::linux`

vulnerability::install::linux

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `vulnerability::install::linux` class:

* [`version`](#version)
* [`temp_dir`](#temp_dir)
* [`root_dir`](#root_dir)
* [`base_url`](#base_url)

##### <a name="version"></a>`version`

Data type: `String[1]`

The version of `grype` to install.

##### <a name="temp_dir"></a>`temp_dir`

Data type: `String[1]`

The temporary directory to use for the installation.
The default value for this is `/tmp`.

##### <a name="root_dir"></a>`root_dir`

Data type: `Stdlib::Absolutepath`

The root directory where all grype files are stored.
This is an internal variable. Please be cautious when changing this.

##### <a name="base_url"></a>`base_url`

Data type: `String[1]`

The base part of the URL where to download grype from.
The default is: `https://github.com/anchore/grype/releases/download`, meaning we download directly from the original github source.

### <a name="vulnerabilityinstallwindows"></a>`vulnerability::install::windows`

vulnerability::install::windows

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `vulnerability::install::windows` class:

* [`version`](#version)
* [`temp_dir`](#temp_dir)
* [`root_dir`](#root_dir)
* [`base_url`](#base_url)

##### <a name="version"></a>`version`

Data type: `String[1]`

The version of `grype` to install.

##### <a name="temp_dir"></a>`temp_dir`

Data type: `Stdlib::Absolutepath`

The temporary directory to use for the installation.
The default value for this is `/tmp`.

##### <a name="root_dir"></a>`root_dir`

Data type: `Stdlib::Absolutepath`

The root directory where all grype files are stored.
This is an internal variable. Please be cautious when changing this.

##### <a name="base_url"></a>`base_url`

Data type: `String[1]`

The base part of the URL where to download grype from.
The default is: `https://github.com/anchore/grype/releases/download`, meaning we download directly from the original github source.

### <a name="vulnerabilitysetup"></a>`vulnerability::setup`

vulnerability::setup

Key settings are:

- directories
- excludes
- ttl_hours

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `vulnerability::setup` class:

* [`cache_dir`](#cache_dir)
* [`config_dir`](#config_dir)
* [`update_url`](#update_url)
* [`ttl_hours`](#ttl_hours)
* [`directories`](#directories)
* [`excludes`](#excludes)
* [`level`](#level)

##### <a name="cache_dir"></a>`cache_dir`

Data type: `Stdlib::Absolutepath`

The `grype` cache directory.
The default values is fine most of the time.
This is an internal variable. Please be cautious when changing this.

##### <a name="config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

The `grype` config directory.
The default values is fine most of the time.
This is an internal variable. Please be cautious when changing this.

##### <a name="update_url"></a>`update_url`

Data type: `String[1]`

The url used for fetching the database updates.

##### <a name="ttl_hours"></a>`ttl_hours`

Data type: `Integer`

This specifies the number of hours you want to keep between different vulnerability scans.
The vulnerability module uses facter to report the CVE's found on a system. Scanning a system, however, is a resource-intensive and time-consuming activity. Therefore we don't want Puppet to do this on every Puppet run.
This parameter specifies the number of hours between new scans. It is the amount of time the fact `cve_list` is deemed valid.
The default value is `24`, meaning a new scan is done once a day.
When you change the setting or update the vulnerability database, the fact is automatically invalidated, so a new scan is done on the next puppet run.

##### <a name="directories"></a>`directories`

Data type: `Array[Stdlib::Absolutepath]`

This parameter contains an Array of strings containing the directories you want to scan for vulnerabilities.
The default value for this is `['/']`. This is safe but also slow. You can speed up the detection of the vulnerabilities by being more specific on the directories you want to scan.

##### <a name="excludes"></a>`excludes`

Data type: `Array[String[1]]`

An array of exclude relative paths of directories and/or files you want to skip during vulnerability scanning.
The default value for this setting is an empty array. This means no files and/or directories will be excludes fropm the scan.

##### <a name="level"></a>`level`

Data type: `Vulnerability::Level`

The severity level of the vulnerabilities you want to report on the system.
Valid values are in order of severity are:
- Critical
- High
- Medium
- Low
- Negligible
- Unknown
When you select a value, vulnerabilities of that level **and higher** will be reported on the system.
When you select one of the lower levels, potentially a lot of CVE's are reported on the CVE list. This might cause strain on your Puppetdb.
The default value is `Medium`

### <a name="vulnerabilityupdate"></a>`vulnerability::update`

vulnerability::update

When a new version is detected, it is downloaded and installed. Also, the `cve_list` fact cache is invalidated, so a new vulnerability scan is executed on the next Puppet run.


See the file "LICENSE" for the full license governing this code.

## Resource types

### <a name="vulnerability_status"></a>`vulnerability_status`

Manage the status of the vulnerabilities on your system.

Using this type, you can start to manage the number of vulnerabilities you allow on your system.
Here is an example on how to use it:

      vulnerability_status { 'master.example.com':
        critical   => 2,
        high       => 90,
        allow_list => ['CVE-2018-11749'],
        when_more  => error,
      }

In this example, you allow a maximum of 2 critical and 90 high vulnerabilities on your system. You#{' '}
know that vulnerability CVE-2018-11749 is on your system and for now, you don't want it to allow this
CVE and not include it in the count.

#### Parameters

The following parameters are available in the `vulnerability_status` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `vulnerability_status` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

## Functions

### <a name="vulnerabilityaffected_files"></a>`vulnerability::affected_files`

Type: Ruby 4.x API

get the list of files that are affected by a specified vulnerability

#### `vulnerability::affected_files()`

get the list of files that are affected by a specified vulnerability

### <a name="vulnerabilitydetected"></a>`vulnerability::detected`

Type: Ruby 4.x API

Determine if a specified vulnerability is found on this system

#### `vulnerability::detected()`

Determine if a specified vulnerability is found on this system

### <a name="vulnerabilityseverity"></a>`vulnerability::severity`

Type: Ruby 4.x API

Return an array of vulnerability id's of a specified level on this system

#### `vulnerability::severity()`

Return an array of vulnerability id's of a specified level on this system

### <a name="vulnerabilityvalidate"></a>`vulnerability::validate`

Type: Ruby 4.x API

Validate that your system doesn't have vulnerabilities above a specified level.
When your system **does** contain the vulnerabilities, signal this to
the puppet server

#### `vulnerability::validate()`

Validate that your system doesn't have vulnerabilities above a specified level.
When your system **does** contain the vulnerabilities, signal this to
the puppet server

## Data types

### <a name="vulnerabilityfix_state"></a>`Vulnerability::Fix_state`

The fix state of the CVE.

Alias of

```puppet
Enum['fixed', 'not-fixed', 'wont-fix', 'unknown']
```

### <a name="vulnerabilitylevel"></a>`Vulnerability::Level`

The severity level of the CVE

Alias of

```puppet
Enum['Critical', 'High', 'Medium', 'Low', 'Negligible', 'Unknown']
```

