# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
module Vulnerability
  # Common selections on the Vulnerability list
  module Selection
    def filter_cves(cve_list, allow_list)
      cve_list.reject { |c| allow_list.include?(c) }
    end

    def level_selection(cve_list, level)
      allowed_levels = allowed_levels(level)
      cve_list.reject { |_c, data| allowed_levels.include?(data['severity']) }
    end

    def all_levels
      %w[Critical High Medium Low Negligible Unknown]
    end

    def selected_levels(level)
      validate_level(level)
      all_levels.select { |e| all_levels.index(e) <= all_levels.index(level) }
    end

    def allowed_levels(level)
      validate_level(level)
      all_levels.select { |e| all_levels.index(e) > all_levels.index(level) }
    end

    def validate_level(level)
      fail "Level #{level} is not a valid level. Use one of: #{all_levels.join(', ')}." unless all_levels.include?(level)
    end
  end
end
