#
# vulnerability::install
#
# @summary This class ensures the installation of `grype` in a correct way so that Puppet can start guarding the vulnerabilities on this system.
#
#
# @param [String[1]] version
#    The version of `grype` to install.
#
# @param [String[1]] base_url
#    The base part of the URL where to download grype from.
#    The default is: `https://github.com/anchore/grype/releases/download`, meaning we download directly from the original github source.
#
#
# See the file "LICENSE" for the full license governing this code.
#
class vulnerability::install (
  String[1] $base_url,
  String[1] $version
) {
  case $facts['kernel'] {
    'Linux': {
      class { 'vulnerability::install::linux':
        version  => $version,
        base_url => $base_url,
      }
      contain vulnerability::install::linux
    }
    'windows': {
      class { 'vulnerability::install::windows':
        version  => $version,
        base_url => $base_url,
      }
      contain vulnerability::install::windows
    }
    default: {
      fail "vulnerability scanning not (yet) supported on ${facts['kernel']}"
    }
  }
}
